Crate servo_allocator

Crate servo_allocator 

Selecting the default global allocator for Servo, and exposing common allocator introspection APIs for memory profiling.

Modules

libc_compat

Structs

Allocator
The default memory allocator provided by the operating system.
HeapReport

Statics

enclosing_size

Functions

dump_unmeasured
heap_reports
is_tracking_unmeasured
usable_size⚠
Get the size of a heap block.